ParamRHLP contains all the parameters of a RHLP model. The parameters are calculated by the initialization Method and then updated by the Method implementing the M-Step of the EM algorithm.
XNumeric vector of length m representing the covariates/inputs \(x_{1},\dots,x_{m}\).
YNumeric vector of length m representing the observed response/output \(y_{1},\dots,y_{m}\).
mNumeric. Length of the response/output vector Y.
KThe number of regimes (RHLP components).
pThe order of the polynomial regression.
qThe dimension of the logistic regression. For the purpose of segmentation, it must be set to 1.
variance_typeCharacter indicating if the model is homoskedastic
(variance_type = "homoskedastic") or heteroskedastic (variance_type = "heteroskedastic"). By default the model is heteroskedastic.
WParameters of the logistic process. \(\boldsymbol{W} =
(\boldsymbol{w}_{1},\dots,\boldsymbol{w}_{K-1})\)
is a matrix of dimension \((q + 1, K - 1)\), with q the order of the
logistic regression. q is fixed to 1 by default.
betaParameters of the polynomial regressions. \(\boldsymbol{\beta}
= (\boldsymbol{\beta}_{1},\dots,\boldsymbol{\beta}_{K})\) is a matrix of dimension \((p + 1, K)\),
with p the order of the polynomial regression. p is fixed to 3 by
default.
sigma2The variances for the K regimes. If RHLP model is
heteroskedastic (variance_type = "heteroskedastic") then sigma2 is a
matrix of size \((K, 1)\) (otherwise RHLP model is homoskedastic
(variance_type = "homoskedastic") and sigma2 is a matrix of size
\((1, 1)\)).
nuThe degree of freedom of the RHLP model representing the complexity of the model.
phiA list giving the regression design matrices for the polynomial and the logistic regressions.
initParam(try_algo = 1)Method to initialize parameters W, beta and
sigma2.
If try_algo = 1 then beta and sigma2 are
initialized by segmenting the time series Y uniformly into
K contiguous segments. Otherwise, W, beta and
sigma2 are initialized by segmenting randomly the time series
Y into K segments.
MStep(statRHLP, verbose_IRLS)Method which implements the M-step of the EM algorithm to learn the
parameters of the RHLP model based on statistics provided by the object
statRHLP of class StatRHLP (which contains the E-step).